@@ -1,22 +1,3 @@
-/*
- * Copyright (C) 2005--2013  ARPA-SIM <urpsim@smr.arpa.emr.it>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
- *
- * Author: Enrico Zini <enrico@enricozini.com>
- */
-
 #include "processor.h"
 
 #include <wreport/bulletin.h>
@@ -29,7 +10,6 @@
 #include "dballe/core/match-wreport.h"
 #include "dballe/msg/aof_codec.h"
 #include "dballe/cmdline/cmdline.h"
-#include "dballe/core/vasprintf.h"
 
 #include <cstring>
 #include <cstdlib>
@@ -48,16 +28,15 @@ namespace cmdline {
 
 void ProcessingException::initmsg(const std::string& fname, unsigned index, const char* msg)
 {
-    char *c;
-    asprintf(&c, "%s:#%u: %s", fname.c_str(), index, msg);
-    msg = c;
-    free(c);
+    char buf[512];
+    snprintf(buf, 512, "%s:#%u: %s", fname.c_str(), index, msg);
+    this->msg = buf;
 }
 
 static void print_parse_error(const BinaryMessage& msg, error& e)
 {
-    fprintf(stderr, "Cannot parse %s message #%d: %s at offset %ld.\n",
-            File::encoding_name(msg.encoding), msg.index, e.what(), msg.offset);
+    fprintf(stderr, "Cannot parse %s message #%d: %s at offset %jd.\n",
+            File::encoding_name(msg.encoding), msg.index, e.what(), (intmax_t)msg.offset);
 }
 
 
@@ -187,28 +166,28 @@ bool Filter::match_index(int idx) const
     if (index == 0 || index[0] == 0)
         return true;
 
-	size_t pos;
-	size_t len;
-	for (pos = 0; (len = strcspn(index + pos, ",")) > 0; pos += len + 1)
-	{
-		int start, end;
-		int found = sscanf(index + pos, "%d-%d", &start, &end);
-		switch (found)
-		{
-			case 1:
-				if (start == idx)
-					return true;
-				break;
-			case 2: 
-				if (start <= idx && idx <= end)
-					return true;
-				break;
-			default:
-				fprintf(stderr, "Cannot parse index string %s\n", index);
-				return false;
-		}
-	}
-	return false;
+    size_t pos;
+    size_t len;
+    for (pos = 0; (len = strcspn(index + pos, ",")) > 0; pos += len + 1)
+    {
+        int start, end;
+        int found = sscanf(index + pos, "%d-%d", &start, &end);
+        switch (found)
+        {
+            case 1:
+                if (start == idx)
+                    return true;
+                break;
+            case 2: 
+                if (start <= idx && idx <= end)
+                    return true;
+                break;
+            default:
+                fprintf(stderr, "Cannot parse index string %s\n", index);
+                return false;
+        }
+    }
+    return false;
 }
 
 bool Filter::match_common(const BinaryMessage&, const Messages* msgs) const
@@ -262,16 +241,16 @@ bool Filter::match_crex(const BinaryMessage& rmsg, const Bulletin* rm, const Mes
     return true;
 
 #if 0
-	if (grepdata->checkdigit != -1)
-	{
-		int checkdigit;
-		DBA_RUN_OR_RETURN(crex_message_has_check_digit(msg, &checkdigit));
-		if (grepdata->checkdigit != checkdigit)
-		{
-			*match = 0;
-			return dba_error_ok();
-		}
-	}
+    if (grepdata->checkdigit != -1)
+    {
+        int checkdigit;
+        DBA_RUN_OR_RETURN(crex_message_has_check_digit(msg, &checkdigit));
+        if (grepdata->checkdigit != checkdigit)
+        {
+            *match = 0;
+            return dba_error_ok();
+        }
+    }
 #endif
 }
 
@@ -283,12 +262,12 @@ bool Filter::match_aof(const BinaryMessage& rmsg, const Messages* msgs) const
     if (!match_common(rmsg, msgs))
         return false;
 
-    if (category != -1)
-        if (category != category)
+    if (this->category != -1)
+        if (this->category != category)
             return false;
 
-    if (subcategory != -1)
-        if (subcategory != subcategory)
+    if (this->subcategory != -1)
+        if (this->subcategory != subcategory)
             return false;
 
     if (msgs) return match_msgs(*msgs);
