@@ -72,9 +72,9 @@ struct DateDayDataSet : public TestDataSet
 
 #define TRY_QUERY(qstring, expected_count) wassert(actual(*f.db).try_data_query(qstring, expected_count))
 
-class Tests : public FixtureTestCase<DBFixture>
+class Tests : public DBFixtureTestCase<DBFixture>
 {
-    using FixtureTestCase::FixtureTestCase;
+    using DBFixtureTestCase::DBFixtureTestCase;
 
     void register_tests() override
     {
@@ -84,7 +84,7 @@ class Tests : public FixtureTestCase<DBFixture>
             char query[20];
             snprintf(query, 20, "ana_id=%d", oldf.data["synop"].info.ana_id);
 #warning FIXME: change after testing if we can move to report-in-station behaviour or not
-            if (f.db->format() == MEM)
+            if (f.db->format() != V6)
                 TRY_QUERY(query, 2);
             else
                 TRY_QUERY(query, 4);
@@ -351,17 +351,9 @@ class Tests : public FixtureTestCase<DBFixture>
             switch (db.format())
             {
                 case MEM:
-                    // mem: coords, ident, datetime, level, trange, code, report
-                    wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals01)); // lat=1, lon=1, year=2000, leveltype1=1, pindicator=1, rep_memo=a, B12101=280.15
-                    wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals07)); // lat=1, lon=1, year=2000, leveltype1=1, pindicator=1, rep_memo=a, B12103=280.15
-                    wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals06)); // lat=1, lon=1, year=2000, leveltype1=1, pindicator=1, rep_memo=b, B12101=280.15
-                    wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals05)); // lat=1, lon=1, year=2000, leveltype1=1, pindicator=2, rep_memo=a, B12101=280.15
-                    wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals04)); // lat=1, lon=1, year=2000, leveltype1=2, pindicator=1, rep_memo=a, B12101=280.15
-                    wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals03)); // lat=1, lon=1, year=2001, leveltype1=1, pindicator=1, rep_memo=a, B12101=280.15
-                    wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals02)); // lat=2, lon=1, year=2000, leveltype1=1, pindicator=1, rep_memo=a, B12101=280.15
-                    break;
                 case V6:
-                    // V6: ana_id, datetime, level, trange, report, var
+                case V7:
+                    // v7: coords, ident, datetime, level, trange, report, code
                     wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals01)); // lat=1, lon=1, year=2000, leveltype1=1, pindicator=1, rep_memo=a, B12101=280.15
                     wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals07)); // lat=1, lon=1, year=2000, leveltype1=1, pindicator=1, rep_memo=a, B12103=280.15
                     wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals06)); // lat=1, lon=1, year=2000, leveltype1=1, pindicator=1, rep_memo=b, B12101=280.15
@@ -369,7 +361,6 @@ class Tests : public FixtureTestCase<DBFixture>
                     wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals04)); // lat=1, lon=1, year=2000, leveltype1=2, pindicator=1, rep_memo=a, B12101=280.15
                     wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals03)); // lat=1, lon=1, year=2001, leveltype1=1, pindicator=1, rep_memo=a, B12101=280.15
                     wassert(actual(cur->next())); wassert(actual(cur).data_matches(vals02)); // lat=2, lon=1, year=2000, leveltype1=1, pindicator=1, rep_memo=a, B12101=280.15
-                    // cur->to_record(test); test.print(stderr);
                     break;
                 default: error_unimplemented::throwf("cannot run this test on a database of format %d", (int)db.format());
             }
@@ -379,14 +370,18 @@ class Tests : public FixtureTestCase<DBFixture>
 
 Tests tg1("db_query_data_mem", nullptr, db::MEM);
 Tests tg2("db_query_data_v6_sqlite", "SQLITE", db::V6);
-#ifdef HAVE_ODBC
-Tests tg4("db_query_data_v6_odbc", "ODBC", db::V6);
-#endif
 #ifdef HAVE_LIBPQ
-Tests tg6("db_query_data_v6_postgresql", "POSTGRESQL", db::V6);
+Tests tg4("db_query_data_v6_postgresql", "POSTGRESQL", db::V6);
 #endif
 #ifdef HAVE_MYSQL
-Tests tg8("db_query_data_v6_mysql", "MYSQL", db::V6);
+Tests tg5("db_query_data_v6_mysql", "MYSQL", db::V6);
+#endif
+Tests tg6("db_query_data_v7_sqlite", "SQLITE", db::V7);
+#ifdef HAVE_LIBPQ
+Tests tg7("db_query_data_v7_postgresql", "POSTGRESQL", db::V7);
+#endif
+#ifdef HAVE_MYSQL
+Tests tg8("db_query_data_v7_mysql", "MYSQL", db::V7);
 #endif
 
 }
