@@ -3,21 +3,24 @@
 #include "dballe/core/aliases.h"
 #include "dballe/core/query.h"
 #include "dballe/var.h"
-#include "dballe/db/sql/repinfo.h"
+#include "dballe/db/v6/repinfo.h"
+#include "dballe/sql/sql.h"
 #include <wreport/var.h>
 #include <regex.h>
 #include <cstring>
 #include <cstdlib>
 #include "config.h"
 #ifdef HAVE_LIBPQ
-#include "dballe/db/postgresql/internals.h"
+#include "dballe/sql/postgresql.h"
 #endif
 #ifdef HAVE_MYSQL
-#include "dballe/db/mysql/internals.h"
+#include "dballe/sql/mysql.h"
 #endif
 
 using namespace std;
 using namespace wreport;
+using dballe::sql::Querybuf;
+using dballe::sql::ServerType;
 
 namespace dballe {
 namespace db {
@@ -310,6 +313,21 @@ bool StationQueryBuilder::build_where()
             break;
     }
 
+    if (!query.rep_memo.empty())
+    {
+        int src_val = db.repinfo().get_id(query.rep_memo.c_str());
+        if (src_val == -1)
+        {
+            sql_where.append_listf("1=0");
+            TRACE("rep_memo %s not found: adding AND 1=0\n", query.rep_memo.c_str());
+        } else {
+            sql_where.append_listf(
+                    "EXISTS(SELECT id FROM data s_repmemo WHERE s_repmemo.id_station=s.id AND s_repmemo.id_report=%d)", src_val);
+            TRACE("found rep_memo %s: adding AND EXISTS(SELECT id FROM data s_repmemo WHERE s_repmemo.id_station=s.id AND s_repmemo.id_report=%d)\n", query.rep_memo.c_str(), src_val);
+        }
+        has_where = true;
+    }
+
     return has_where;
 }
 
@@ -442,16 +460,16 @@ bool QueryBuilder::add_pa_where(const char* tbl)
             // that can be compiled out
             ;
 #if HAVE_LIBPQ
-        } else if (PostgreSQLConnection* c = dynamic_cast<PostgreSQLConnection*>(&conn)) {
+        } else if (dynamic_cast<dballe::sql::PostgreSQLConnection*>(&conn)) {
             sql_where.append_listf("%s.ident=$1::text", tbl);
             bind_in_ident = query.ident.get();
             TRACE("found ident: adding AND %s.ident=$1::text.  val is %s\n", tbl, query.ident.get());
 #endif
 #if HAVE_MYSQL
-        } else if (MySQLConnection* c = dynamic_cast<MySQLConnection*>(&conn)) {
+        } else if (dballe::sql::MySQLConnection* c = dynamic_cast<dballe::sql::MySQLConnection*>(&conn)) {
             string escaped = c->escape(query.ident.get());
             sql_where.append_listf("%s.ident='%s'", tbl, escaped.c_str());
-            TRACE("found ident: adding AND %s.ident='%s'.  val is %s\n", tbl, escape.c_str(), query.ident.get());
+            TRACE("found ident: adding AND %s.ident='%s'.  val is %s\n", tbl, escaped.c_str(), query.ident.get());
 #endif
         } else {
             sql_where.append_listf("%s.ident=?", tbl);
@@ -518,8 +536,8 @@ bool QueryBuilder::add_dt_where(const char* tbl)
             // Add constraint on the exact date interval
             sql_where.append_listf("%s.datetime=", tbl);
             conn.add_datetime(sql_where, dtmin);
-            TRACE("found exact time: adding AND %s.datetime={ts '%04d-%02d-%02d %02d:%02d:%02d.000'}\n",
-                    tbl, minvalues[0], minvalues[1], minvalues[2], minvalues[3], minvalues[4], minvalues[5]);
+            TRACE("found exact time: adding AND %s.datetime=%04hu-%02hhu-%02hhu%c%02hhu:%02hhu:%02hhu\n",
+                    tbl, dtmin.year, dtmin.month, dtmin.day, dtmin.hour, dtmin.minute, dtmin.second);
             found = true;
         }
         else
@@ -529,16 +547,16 @@ bool QueryBuilder::add_dt_where(const char* tbl)
                 // Add constraint on the minimum date interval
                 sql_where.append_listf("%s.datetime>=", tbl);
                 conn.add_datetime(sql_where, dtmin);
-                TRACE("found min time: adding AND %s.datetime>={ts '%04d-%02d-%02d %02d:%02d:%02d.000'}\n",
-                    tbl, minvalues[0], minvalues[1], minvalues[2], minvalues[3], minvalues[4], minvalues[5]);
+                TRACE("found min time: adding AND %s.datetime>=%04hu-%02hhu-%02hhu%c%02hhu:%02hhu:%02hhu\n",
+                    tbl, dtmin.year, dtmin.month, dtmin.day, dtmin.hour, dtmin.minute, dtmin.second);
                 found = true;
             }
             if (!dtmax.is_missing())
             {
                 sql_where.append_listf("%s.datetime<=", tbl);
                 conn.add_datetime(sql_where, dtmax);
-                TRACE("found max time: adding AND %s.datetime<={ts '%04d-%02d-%02d %02d:%02d:%02d.000'}\n",
-                        tbl, maxvalues[0], maxvalues[1], maxvalues[2], maxvalues[3], maxvalues[4], maxvalues[5]);
+                TRACE("found max time: adding AND %s.datetime<=%04hu-%02hhu-%02hhu%c%02hhu:%02hhu:%02hhu\n",
+                    tbl, dtmax.year, dtmax.month, dtmax.day, dtmax.hour, dtmax.minute, dtmax.second);
                 found = true;
             }
         }
@@ -606,7 +624,7 @@ bool QueryBuilder::add_varcode_where(const char* tbl)
             sql_where.append_listf("%s.id_var IN (", tbl);
             sql_where.append_varlist(query.varcodes);
             sql_where.append(")");
-            TRACE("found blist: adding AND %s.id_var IN (%s)\n", tbl, val);
+            TRACE("found blist: adding AND %s.id_var IN (...%zd items...)\n", tbl, query.varcodes.size());
             found = true;
             break;
     }
@@ -617,7 +635,7 @@ bool QueryBuilder::add_varcode_where(const char* tbl)
 bool QueryBuilder::add_repinfo_where(const char* tbl)
 {
     bool found = false;
- 
+
     if (query.prio_min != MISSING_INT || query.prio_max != MISSING_INT)
     {
         // Filter the repinfo cache and build a IN query
@@ -643,8 +661,14 @@ bool QueryBuilder::add_repinfo_where(const char* tbl)
     if (!query.rep_memo.empty())
     {
         int src_val = db.repinfo().get_id(query.rep_memo.c_str());
-        sql_where.append_listf("%s.id_report=%d", tbl, src_val);
-        TRACE("found rep_memo %s: adding AND %s.id_report=%d\n", val, tbl, (int)src_val);
+        if (src_val == -1)
+        {
+            sql_where.append_listf("1=0");
+            TRACE("rep_memo %s not found: adding AND 1=0\n", query.rep_memo.c_str());
+        } else {
+            sql_where.append_listf("%s.id_report=%d", tbl, src_val);
+            TRACE("found rep_memo %s: adding AND %s.id_report=%d\n", query.rep_memo.c_str(), tbl, (int)src_val);
+        }
         found = true;
     }
 
