@@ -1,7 +1,7 @@
 /*
  * msg/codec - General codec options
  *
- * Copyright (C) 2005--2010  ARPA-SIM <urpsim@smr.arpa.emr.it>
+ * Copyright (C) 2005--2015  ARPA-SIM <urpsim@smr.arpa.emr.it>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +22,8 @@
 #include "codec.h"
 #include "aof_codec.h"
 #include "wr_codec.h"
-#include <dballe/core/rawmsg.h>
 #include <wreport/error.h>
+#include <wreport/bulletin.h>
 
 #include "config.h"
 
@@ -65,18 +65,25 @@ Importer::~Importer()
 {
 }
 
-std::auto_ptr<Importer> Importer::create(Encoding type, const Options& opts)
+Messages Importer::from_binary(const BinaryMessage& msg) const
+{
+    Messages res;
+    foreach_decoded(msg, [&](unique_ptr<Message>&& m) { res.append(move(m)); return true; });
+    return res;
+}
+
+std::unique_ptr<Importer> Importer::create(File::Encoding type, const Options& opts)
 {
     switch (type)
     {
-        case BUFR:
-            return auto_ptr<Importer>(new BufrImporter(opts));
-        case CREX:
-            return auto_ptr<Importer>(new CrexImporter(opts));
-        case AOF:
-            return auto_ptr<Importer>(new AOFImporter(opts));
+        case File::BUFR:
+            return unique_ptr<Importer>(new BufrImporter(opts));
+        case File::CREX:
+            return unique_ptr<Importer>(new CrexImporter(opts));
+        case File::AOF:
+            return unique_ptr<Importer>(new AOFImporter(opts));
         default:
-            error_unimplemented::throwf("%s importer is not implemented yet", encoding_name(type));
+            error_unimplemented::throwf("%s importer is not implemented yet", File::encoding_name(type));
     }
 }
 
@@ -128,23 +135,23 @@ Exporter::~Exporter()
 {
 }
 
-std::auto_ptr<wreport::Bulletin> Exporter::make_bulletin() const
+std::unique_ptr<wreport::Bulletin> Exporter::make_bulletin() const
 {
-    return std::auto_ptr<wreport::Bulletin>(0);
+    return std::unique_ptr<wreport::Bulletin>(nullptr);
 }
 
-std::auto_ptr<Exporter> Exporter::create(Encoding type, const Options& opts)
+std::unique_ptr<Exporter> Exporter::create(File::Encoding type, const Options& opts)
 {
     switch (type)
     {
-        case BUFR:
-            return auto_ptr<Exporter>(new BufrExporter(opts));
-        case CREX:
-            return auto_ptr<Exporter>(new CrexExporter(opts));
-        case AOF:
-            //return auto_ptr<Exporter>(new AOFExporter(opts));
+        case File::BUFR:
+            return unique_ptr<Exporter>(new BufrExporter(opts));
+        case File::CREX:
+            return unique_ptr<Exporter>(new CrexExporter(opts));
+        case File::AOF:
+            //return unique_ptr<Exporter>(new AOFExporter(opts));
         default:
-            error_unimplemented::throwf("%s exporter is not implemented yet", encoding_name(type));
+            error_unimplemented::throwf("%s exporter is not implemented yet", File::encoding_name(type));
     }
 }
 
