@@ -48,7 +48,7 @@ static int op_precise_import = 0;
 static int op_bufr2netcdf_categories = 0;
 static const char* op_output_type = "bufr";
 static const char* op_output_template = "";
-static const char* op_output_file = "(stdout)";
+static const char* op_output_file = NULL;
 static const char* op_report = "";
 static const char* op_bisect_cmd = NULL;
 int op_verbose = 0;
@@ -292,11 +292,13 @@ struct CSVBulletin : public cmdline::Action
 /**
  * Print a Msgs in CSV format
  */
+
 struct CSVMsgs : public cmdline::Action
 {
     bool first;
+    FileCSV writer;
 
-    CSVMsgs() : first(true) {}
+    CSVMsgs() : first(true), writer(stdout) {}
 
     virtual bool operator()(const cmdline::Item& item)
     {
@@ -304,12 +306,12 @@ struct CSVMsgs : public cmdline::Action
 
         if (first)
         {
-            Msg::csv_header(cout);
+            Msg::csv_header(writer);
             first = false;
         }
 
         for (const auto& mi: *item.msgs)
-            Msg::downcast(mi).to_csv(cout);
+            Msg::downcast(mi).to_csv(writer);
         return true;
     }
 };
@@ -571,7 +573,7 @@ struct WriteRaw : public cmdline::Action
     virtual bool operator()(const cmdline::Item& item)
     {
         if (!item.rmsg) return false;
-        if (!file) file = File::create(item.rmsg->encoding, "(stdout)", "w").release();
+        if (!file) file = File::create(item.rmsg->encoding, stdout, false, "(stdout)").release();
         file->write(item.rmsg->data);
         return true;
     }
@@ -964,10 +966,17 @@ struct Convert : public cmdline::Subcommand
 
         conv.bufr2netcdf_categories = op_bufr2netcdf_categories != 0;
 
-        if (strcmp(op_output_type, "auto") == 0)
-            conv.file = File::create(op_output_file, "w").release();
-        else
-            conv.file = File::create(string_to_encoding(op_output_type), op_output_file, "w").release();
+        if (strcmp(op_output_type, "auto") == 0) {
+            if (op_output_file == NULL)
+                conv.file = File::create(stdout, false, "stdout").release();
+            else
+                conv.file = File::create(op_output_file, "w").release();
+        } else {
+            if (op_output_file == NULL)
+                conv.file = File::create(string_to_encoding(op_output_type), stdout, false, "stdout").release();
+            else
+                conv.file = File::create(string_to_encoding(op_output_type), op_output_file, "w").release();
+        }
 
         conv.exporter = msg::Exporter::create(conv.file->encoding(), opts).release();
 
